``hubward``
===========

.. image:: https://travis-ci.org/daler/hubward.svg
    :target: https://travis-ci.org/daler/hubward

A common question when reading an interesting paper is, "how does relate to my
favorite gene locus?". To address this question, usually we need to download
the supplemental data, figure out what format it's in, convert it to some other
useful format, and visualize it alongside our own data.

`hubward` helps manage this process, lowering the effort required to track,
manage, organize, and upload many studies for cross-comparison in the UCSC
Genome Browser.

Data are organized into `track hubs
<https://genome.ucsc.edu/goldenPath/help/hgTrackHubHelp.html>`_ on the UCSC
Genome Browser, and the name `hubward` indicates the direction in which data
are moved into these track hubs. It can also refer to a direction in `other
complex systems <http://wiki.lspace.org/mediawiki/Hubwards>`_.

The separate repository, `hubward-studies
<https://github.com/daler/hubward-studies>`_, contains examples of prepared
track hubs. Subsets of these can be combined into user-defined hubs, or can
serve as examples for preparing other studies.

Documentation can be found at `<https://daler.github.io/hubward>`_.

Overview
--------
`This poster`_ gives an overview of `hubward`, and provides a worked example.

Further details can be found in the `full documentation <https://daler.github.io/hubward>`_.
